/*
	FreeRTOS.org V6.0.5 - Copyright (C) 2003-2007 Richard Barry.

	This file is part of the FreeRTOS.org distribution.

	FreeRTOS.org is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	FreeRTOS.org is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with FreeRTOS.org; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	A special exception to the GPL can be applied should you wish to distribute
	a combined work that includes FreeRTOS.org, without being obliged to provide
	the source code for any proprietary components.  See the licensing section
	of http://www.FreeRTOS.org for full details of how and when the exception
	can be applied.

	***************************************************************************
	See http://www.FreeRTOS.org for documentation, latest information, license
	and contact details.  Please ensure to read the configuration and relevant
	port sections of the online documentation.

	Also see http://www.SafeRTOS.com a version that has been certified for use
	in safety critical systems, plus commercial licensing, development and
	support options.
	***************************************************************************
*/

/*
 * This demo is configured to execute on a controller board from a Jennic JN5139
 * Evaluation Kit. LED are simulated on the LCD fitted to this board.
 */

/* Scheduler includes. */
#include "FreeRTOS.h"
#include "task.h"

/* Demo application includes. */
#include "partest.h"

/* Hardware Includes */
#include <LcdDriver.h>

/* Constants required to access the LED's. */
#define partstNUM_LEDS			( ( unsigned portCHAR ) 6 )

/*-----------------------------------------------------------*/

void vParTestInitialise( void )
{
	unsigned portBASE_TYPE uxLED;

    vLcdResetDefault();

	vLcdWriteText("LED0", 0, 0);
	vLcdWriteText("LED1", 1, 0);
	vLcdWriteText("LED2", 2, 0);
	vLcdWriteText("LED3", 3, 0);
	vLcdWriteText("LED4", 4, 0);
	vLcdWriteText("LED5", 5, 0);

	vLcdRefreshAll();

	/* Turn all LEDs off */
	for (uxLED = 0; uxLED < partstNUM_LEDS; uxLED++)
	{
		vParTestSetLED( uxLED, 0 );
	}
}
/*-----------------------------------------------------------*/

void vParTestSetLED( unsigned portBASE_TYPE uxLED, signed portBASE_TYPE xValue )
{
	/* Set or clear the output */
	if( uxLED < ( portBASE_TYPE ) partstNUM_LEDS )
	{
		vTaskSuspendAll();
		{
			portCHAR acLedState[2];

			acLedState[0] = ' ';

			if( xValue )
			{
				acLedState[1] = '&';

				/* Output LED on symbol */
				vLcdWriteText(acLedState, uxLED, 30);
			}
			else
			{
				acLedState[1] = ',';

				/* Output LED off symbol */
				vLcdWriteText(acLedState, uxLED, 30);
			}
			vLcdRefreshAll();
		}
		xTaskResumeAll();
	}
}

/*-----------------------------------------------------------*/

void vParTestToggleLED( unsigned portBASE_TYPE uxLED )
{
	static unsigned portCHAR acState[partstNUM_LEDS];

	if( uxLED < ( portBASE_TYPE ) partstNUM_LEDS )
	{
		vTaskSuspendAll();
		{
			if (acState[uxLED] == 0)
			{
				vParTestSetLED( uxLED, 1 );
				acState[uxLED] = 1;
			}
			else
			{
				vParTestSetLED( uxLED, 0 );
				acState[uxLED] = 0;
			}
		}
		xTaskResumeAll();
	}
}

/*-----------------------------------------------------------*/
